from django.forms import (
    CharField,
    CheckboxSelectMultiple,
    MultipleChoiceField,
)
from django.utils.translation import ugettext_lazy as _
from i18nfield.forms import I18nFormField, I18nTextInput
from pretix.base.forms import SettingsForm


class KeycloakCreatorForm(SettingsForm):
    keycloak_create_user_items = MultipleChoiceField(
        widget=CheckboxSelectMultiple(attrs={"class": "scrolling-multiple-choice"}),
        label=_("Ask Username for"),
        required=True,
        choices=[],
        help_text=_("These products will ask for a username."),
    )
    keycloak_create_user_authorization_token = CharField(
        label=_("Access token"),
        strip=True,
        help_text=_(
            "Access token for the keycloak server. "
        ),
    )
    keycloak_create_user_realm_url = CharField(
        label=_("Keycloak realm url"),
        strip=True,
        help_text=_("The url to keycloak including realm."),
    )
    keycloak_create_user_hint = I18nFormField(
        widget=I18nTextInput,
        label=_("Username field help text"),
        required=True,
        help_text=_(
            "Explains what to enter"
        ),
    )

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["keycloak_create_user_items"].choices = [
            (i.pk, i.name) for i in self.obj.items.all()
        ]
